aboutsummaryrefslogtreecommitdiffstats
path: root/libical/src/libical
diff options
context:
space:
mode:
authorSeth Alves <alves@src.gnome.org>2000-06-07 07:23:16 +0800
committerSeth Alves <alves@src.gnome.org>2000-06-07 07:23:16 +0800
commit8eed9eb22f19da2880e786a5a9a254bb2a7da25b (patch)
treee53b9a2396d09753940ad7cac7d1a3beb219be26 /libical/src/libical
parent4b82b86ee5df1cfcbcbc46cc421804a6a0cb8da2 (diff)
downloadgsoc2013-evolution-8eed9eb22f19da2880e786a5a9a254bb2a7da25b.tar
gsoc2013-evolution-8eed9eb22f19da2880e786a5a9a254bb2a7da25b.tar.gz
gsoc2013-evolution-8eed9eb22f19da2880e786a5a9a254bb2a7da25b.tar.bz2
gsoc2013-evolution-8eed9eb22f19da2880e786a5a9a254bb2a7da25b.tar.lz
gsoc2013-evolution-8eed9eb22f19da2880e786a5a9a254bb2a7da25b.tar.xz
gsoc2013-evolution-8eed9eb22f19da2880e786a5a9a254bb2a7da25b.tar.zst
gsoc2013-evolution-8eed9eb22f19da2880e786a5a9a254bb2a7da25b.zip
*** empty log message ***
svn path=/trunk/; revision=3451
Diffstat (limited to 'libical/src/libical')
-rw-r--r--libical/src/libical/icallexer.c2
-rw-r--r--libical/src/libical/icalyacc.c11
2 files changed, 6 insertions, 7 deletions
diff --git a/libical/src/libical/icallexer.c b/libical/src/libical/icallexer.c
index 0cf532cff6..a7f0f206cb 100644
--- a/libical/src/libical/icallexer.c
+++ b/libical/src/libical/icallexer.c
@@ -748,7 +748,7 @@ YY_MALLOC_DECL
YY_DECL
{
register yy_state_type yy_current_state;
- register char *yy_cp, *yy_bp;
+ register char *yy_cp = NULL, *yy_bp = NULL;
register int yy_act;
#line 92 "icallexer.l"
diff --git a/libical/src/libical/icalyacc.c b/libical/src/libical/icalyacc.c
index fa6a073282..46de31370d 100644
--- a/libical/src/libical/icalyacc.c
+++ b/libical/src/libical/icalyacc.c
@@ -1,7 +1,6 @@
/* A Bison parser, made from icalyacc.y
- by GNU Bison version 1.27
- */
+ by GNU Bison version 1.28 */
#define YYBISON 1 /* Identify Bison output. */
@@ -401,7 +400,7 @@ static const char * const yytname[] = { "$","error","$undefined.","DIGITS",
"TEXT","THISANDFUTURE","THISANDPRIOR","TIME","TRANSPAENT","UNKNOWN","UTCOFFSET",
"XNAME","ALTREP","CN","CUTYPE","DAYLIGHT","DIR","ENCODING","EVENT","FBTYPE",
"FMTTYPE","LANGUAGE","MEMBER","PARTSTAT","RANGE","RELATED","RELTYPE","ROLE",
-"RSVP","SENTBY","STANDARD","URI","TIME_CHAR","UTC_CHAR","\"unimplemented2\\\"",
+"RSVP","SENTBY","STANDARD","URI","TIME_CHAR","UTC_CHAR","\"unimplemented2\"",
"'W'","'H'","'M'","'S'","'D'","'+'","'-'","'P'","'/'","value","binary_value",
"boolean_value","date_value","utc_char","utc_char_b","datetime_value","dur_date",
"dur_week","dur_time","dur_hour","dur_minute","dur_second","dur_day","dur_prefix",
@@ -519,7 +518,7 @@ static const short yycheck[] = { 1,
};
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
#line 3 "/usr/lib/bison.simple"
/* This file comes from bison-1.27. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.
@@ -732,7 +731,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
#endif
#endif
-#line 216 "/usr/lib/bison.simple"
+#line 217 "/usr/lib/bison.simple"
/* The user can define YYPARSE_PARAM as the name of an argument to be passed
into yyparse. The argument should have type void *.
@@ -1441,7 +1440,7 @@ case 84:
break;}
}
/* the action file gets copied in in place of this dollarsign */
-#line 542 "/usr/lib/bison.simple"
+#line 543 "/usr/lib/bison.simple"
yyvsp -= yylen;
yyssp -= yylen;
@@ -519,7 +518,7 @@ static const short yycheck[] = { 1,
/* -*-C-*- Note some compilers choke on comments on `#line' lines. */
#line 3 "/usr/lib/bison.simple"
-/* This file comes from bison-1.27. */
+/* This file comes from bison-1.28. */
/* Skeleton output parser for bison,
Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.